window.Gleam.initSearch([{"doc":"kreator","title":"kreator","content":"# kreator\n\n[![Package Version](https://img.shields.io/hexpm/v/kreator)](https://hex.pm/packages/kreator)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/kreator/)\n\n```sh\ngleam add kreator\n```\n\nThis is a very wip query builder made in pure gleam to be used with multiple DB dialects.\n\n```gleam\nimport kreator as k\nimport kreator/sqlight as ks\nimport kreator/where.{and_where_equals}\nimport kreator/value as v\nimport gleam/dynamic\nimport sqlight\n\npub fn main() {\n    use conn &lt;- sqlight.with_connection(&quot;:memory:&quot;)\n    let assert Ok(_) = sqlight.exec(\n      &quot;create table users (id integer primary key autoincrement, email text, name text)&quot;,\n      conn,\n    )\n\n    let insert_user_query =\n        k.table(&quot;users&quot;)\n        |&gt; k.insert([#(&quot;email&quot;, v.string(&quot;b@b.com&quot;)), #(&quot;name&quot;, v.string(&quot;Bruno&quot;))])\n        |&gt; k.to_sqlite()\n\n    let select_user_query =\n        k.table(&quot;users&quot;)\n        |&gt; k.where(and_where_equals(_, &quot;id&quot;, v.int(1)))\n        |&gt; k.to_sqlite()\n\n    let assert Ok(_) = ks.run_nil(insert_user_query, on: conn)\n\n    let assert Ok(user) = ks.first(\n        select_user_query,\n        on: conn,\n        expecting: dynamic.tupple3(dynamic.int, dynamic.string, dynamic.string)\n    )\n\n    io.debug(user) // #(1, &quot;b@b.com&quot;, &quot;Bruno&quot;)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/kreator&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n#### TODO\n- [ ] add codec support generated from schema files\n- [ ] add joins\n- [ ] add aggregations\n- [ ] add subqueries\n- [ ] add pagination helpers\n","url":"index.html"},{"doc":"kreator/dialect","title":"Dialect","content":"pub type Dialect {\n  SQLite\n  Postgres\n  MySQL\n}\n\nSQLite\n\n\nPostgres\n\n\nMySQL\n\n\nSynonyms:\nkreator/dialect.Dialect\nkreator/dialect Dialect","url":"kreator/dialect.html#Dialect"},{"doc":"kreator/dialect","title":"string_quote","content":"pub fn string_quote(dialect: Dialect) -&gt; String\n\nSynonyms:\nkreator/dialect.string_quote\nkreator/dialect string_quote","url":"kreator/dialect.html#string_quote"},{"doc":"kreator/dialect","title":"symbol_quote","content":"pub fn symbol_quote(dialect: Dialect) -&gt; String\n\nSynonyms:\nkreator/dialect.symbol_quote\nkreator/dialect symbol_quote","url":"kreator/dialect.html#symbol_quote"},{"doc":"kreator/dialect","title":"wrap_column","content":"pub fn wrap_column(\n  column: String,\n  dialect: Dialect,\n) -&gt; StringBuilder\n\nSynonyms:\nkreator/dialect.wrap_column\nkreator/dialect wrap_column","url":"kreator/dialect.html#wrap_column"},{"doc":"kreator/dialect","title":"kreator/dialect","content":"","url":"kreator/dialect.html"},{"doc":"kreator/order","title":"Direction","content":"pub type Direction {\n  Ascending\n  Descending\n}\n\nAscending\n\n\nDescending\n\n\nSynonyms:\nkreator/order.Direction\nkreator/order Direction","url":"kreator/order.html#Direction"},{"doc":"kreator/order","title":"Order","content":"pub type Order =\n  #(String, Direction)\n\n\nSynonyms:\nkreator/order.Order\nkreator/order Order","url":"kreator/order.html#Order"},{"doc":"kreator/order","title":"to_string","content":"pub fn to_string(\n  order: #(String, Direction),\n  dialect: Dialect,\n) -&gt; StringBuilder\n\nSynonyms:\nkreator/order.to_string\nkreator/order to_string","url":"kreator/order.html#to_string"},{"doc":"kreator/order","title":"type_to_string","content":"pub fn type_to_string(direction: Direction) -&gt; String\n\nSynonyms:\nkreator/order.type_to_string\nkreator/order type_to_string","url":"kreator/order.html#type_to_string"},{"doc":"kreator/order","title":"kreator/order","content":"","url":"kreator/order.html"},{"doc":"kreator/value","title":"Value","content":"pub type Value {\n  String(String)\n  Int(Int)\n  Float(Float)\n  Bool(Bool)\n  Raw(String)\n  Null\n  List(List(Value))\n}\n\nString(String)\n\n\nInt(Int)\n\n\nFloat(Float)\n\n\nBool(Bool)\n\n\nRaw(String)\n\n\nNull\n\n\nList(List(Value))\n\n\nSynonyms:\nkreator/value.Value\nkreator/value Value","url":"kreator/value.html#Value"},{"doc":"kreator/value","title":"bool","content":"pub fn bool(i: Bool) -&gt; Value\n\nSynonyms:\nkreator/value.bool\nkreator/value bool","url":"kreator/value.html#bool"},{"doc":"kreator/value","title":"float","content":"pub fn float(i: Float) -&gt; Value\n\nSynonyms:\nkreator/value.float\nkreator/value float","url":"kreator/value.html#float"},{"doc":"kreator/value","title":"int","content":"pub fn int(i: Int) -&gt; Value\n\nSynonyms:\nkreator/value.int\nkreator/value int","url":"kreator/value.html#int"},{"doc":"kreator/value","title":"list","content":"pub fn list(i: List(Value)) -&gt; Value\n\nSynonyms:\nkreator/value.list\nkreator/value list","url":"kreator/value.html#list"},{"doc":"kreator/value","title":"null","content":"pub fn null() -&gt; Value\n\nSynonyms:\nkreator/value.null\nkreator/value null","url":"kreator/value.html#null"},{"doc":"kreator/value","title":"raw","content":"pub fn raw(i: String) -&gt; Value\n\nSynonyms:\nkreator/value.raw\nkreator/value raw","url":"kreator/value.html#raw"},{"doc":"kreator/value","title":"string","content":"pub fn string(i: String) -&gt; Value\n\nSynonyms:\nkreator/value.string\nkreator/value string","url":"kreator/value.html#string"},{"doc":"kreator/value","title":"to_placeholder","content":"pub fn to_placeholder(value: Value) -&gt; StringBuilder\n\nSynonyms:\nkreator/value.to_placeholder\nkreator/value to_placeholder","url":"kreator/value.html#to_placeholder"},{"doc":"kreator/value","title":"kreator/value","content":"","url":"kreator/value.html"},{"doc":"kreator/where","title":"Operator","content":"pub type Operator {\n  Eq\n  Gt\n  Lt\n  GtEq\n  LtEq\n  NotEq\n  Like\n  NotLike\n  IsNull\n  IsNotNull\n  In\n  NotIn\n}\n\nEq\n\n\nGt\n\n\nLt\n\n\nGtEq\n\n\nLtEq\n\n\nNotEq\n\n\nLike\n\n\nNotLike\n\n\nIsNull\n\n\nIsNotNull\n\n\nIn\n\n\nNotIn\n\n\nSynonyms:\nkreator/where.Operator\nkreator/where Operator","url":"kreator/where.html#Operator"},{"doc":"kreator/where","title":"Where","content":"pub type Where {\n  WhereBasic(\n    where_type: WhereType,\n    column: String,\n    operator: Operator,\n    value: Value,\n  )\n  WhereWrapped(where_type: WhereType, list: List(Where))\n}\n\nWhereBasic(\n  where_type: WhereType,\n  column: String,\n  operator: Operator,\n  value: Value,\n)\n\n\nWhereWrapped(where_type: WhereType, list: List(Where))\n\n\nSynonyms:\nkreator/where.Where\nkreator/where Where","url":"kreator/where.html#Where"},{"doc":"kreator/where","title":"WhereType","content":"pub type WhereType {\n  And\n  Or\n}\n\nAnd\n\n\nOr\n\n\nSynonyms:\nkreator/where.WhereType\nkreator/where WhereType","url":"kreator/where.html#WhereType"},{"doc":"kreator/where","title":"add","content":"pub fn add(\n  where_list: List(Where),\n  new_where: Where,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.add\nkreator/where add","url":"kreator/where.html#add"},{"doc":"kreator/where","title":"and_where_equals","content":"pub fn and_where_equals(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.and_where_equals\nkreator/where and_where_equals","url":"kreator/where.html#and_where_equals"},{"doc":"kreator/where","title":"and_where_gt","content":"pub fn and_where_gt(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.and_where_gt\nkreator/where and_where_gt","url":"kreator/where.html#and_where_gt"},{"doc":"kreator/where","title":"and_where_gte","content":"pub fn and_where_gte(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.and_where_gte\nkreator/where and_where_gte","url":"kreator/where.html#and_where_gte"},{"doc":"kreator/where","title":"and_where_in","content":"pub fn and_where_in(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.and_where_in\nkreator/where and_where_in","url":"kreator/where.html#and_where_in"},{"doc":"kreator/where","title":"and_where_like","content":"pub fn and_where_like(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.and_where_like\nkreator/where and_where_like","url":"kreator/where.html#and_where_like"},{"doc":"kreator/where","title":"and_where_lt","content":"pub fn and_where_lt(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.and_where_lt\nkreator/where and_where_lt","url":"kreator/where.html#and_where_lt"},{"doc":"kreator/where","title":"and_where_lte","content":"pub fn and_where_lte(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.and_where_lte\nkreator/where and_where_lte","url":"kreator/where.html#and_where_lte"},{"doc":"kreator/where","title":"and_where_not_equals","content":"pub fn and_where_not_equals(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.and_where_not_equals\nkreator/where and_where_not_equals","url":"kreator/where.html#and_where_not_equals"},{"doc":"kreator/where","title":"and_where_not_in","content":"pub fn and_where_not_in(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.and_where_not_in\nkreator/where and_where_not_in","url":"kreator/where.html#and_where_not_in"},{"doc":"kreator/where","title":"and_where_not_like","content":"pub fn and_where_not_like(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.and_where_not_like\nkreator/where and_where_not_like","url":"kreator/where.html#and_where_not_like"},{"doc":"kreator/where","title":"and_where_not_null","content":"pub fn and_where_not_null(\n  where_list: List(Where),\n  column: String,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.and_where_not_null\nkreator/where and_where_not_null","url":"kreator/where.html#and_where_not_null"},{"doc":"kreator/where","title":"and_where_null","content":"pub fn and_where_null(\n  where_list: List(Where),\n  column: String,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.and_where_null\nkreator/where and_where_null","url":"kreator/where.html#and_where_null"},{"doc":"kreator/where","title":"equals","content":"pub fn equals(\n  column column: String,\n  value value: Value,\n  where_type where_type: WhereType,\n) -&gt; Where\n\nSynonyms:\nkreator/where.equals\nkreator/where equals","url":"kreator/where.html#equals"},{"doc":"kreator/where","title":"flatten","content":"pub fn flatten(\n  where_list: List(Where),\n) -&gt; List(#(WhereType, String, Operator, Value))\n\nSynonyms:\nkreator/where.flatten\nkreator/where flatten","url":"kreator/where.html#flatten"},{"doc":"kreator/where","title":"gt","content":"pub fn gt(\n  column column: String,\n  value value: Value,\n  where_type where_type: WhereType,\n) -&gt; Where\n\nSynonyms:\nkreator/where.gt\nkreator/where gt","url":"kreator/where.html#gt"},{"doc":"kreator/where","title":"gte","content":"pub fn gte(\n  column column: String,\n  value value: Value,\n  where_type where_type: WhereType,\n) -&gt; Where\n\nSynonyms:\nkreator/where.gte\nkreator/where gte","url":"kreator/where.html#gte"},{"doc":"kreator/where","title":"in","content":"pub fn in(\n  column column: String,\n  value value: Value,\n  where_type where_type: WhereType,\n) -&gt; Where\n\nSynonyms:\nkreator/where.in\nkreator/where in","url":"kreator/where.html#in"},{"doc":"kreator/where","title":"like","content":"pub fn like(\n  column column: String,\n  value value: Value,\n  where_type where_type: WhereType,\n) -&gt; Where\n\nSynonyms:\nkreator/where.like\nkreator/where like","url":"kreator/where.html#like"},{"doc":"kreator/where","title":"lt","content":"pub fn lt(\n  column column: String,\n  value value: Value,\n  where_type where_type: WhereType,\n) -&gt; Where\n\nSynonyms:\nkreator/where.lt\nkreator/where lt","url":"kreator/where.html#lt"},{"doc":"kreator/where","title":"lte","content":"pub fn lte(\n  column column: String,\n  value value: Value,\n  where_type where_type: WhereType,\n) -&gt; Where\n\nSynonyms:\nkreator/where.lte\nkreator/where lte","url":"kreator/where.html#lte"},{"doc":"kreator/where","title":"new_where_list","content":"pub fn new_where_list() -&gt; List(Where)\n\nSynonyms:\nkreator/where.new_where_list\nkreator/where new_where_list","url":"kreator/where.html#new_where_list"},{"doc":"kreator/where","title":"not_equals","content":"pub fn not_equals(\n  column column: String,\n  value value: Value,\n  where_type where_type: WhereType,\n) -&gt; Where\n\nSynonyms:\nkreator/where.not_equals\nkreator/where not_equals","url":"kreator/where.html#not_equals"},{"doc":"kreator/where","title":"not_in","content":"pub fn not_in(\n  column column: String,\n  value value: Value,\n  where_type where_type: WhereType,\n) -&gt; Where\n\nSynonyms:\nkreator/where.not_in\nkreator/where not_in","url":"kreator/where.html#not_in"},{"doc":"kreator/where","title":"not_like","content":"pub fn not_like(\n  column column: String,\n  value value: Value,\n  where_type where_type: WhereType,\n) -&gt; Where\n\nSynonyms:\nkreator/where.not_like\nkreator/where not_like","url":"kreator/where.html#not_like"},{"doc":"kreator/where","title":"not_null","content":"pub fn not_null(\n  column column: String,\n  where_type where_type: WhereType,\n) -&gt; Where\n\nSynonyms:\nkreator/where.not_null\nkreator/where not_null","url":"kreator/where.html#not_null"},{"doc":"kreator/where","title":"null","content":"pub fn null(\n  column column: String,\n  where_type where_type: WhereType,\n) -&gt; Where\n\nSynonyms:\nkreator/where.null\nkreator/where null","url":"kreator/where.html#null"},{"doc":"kreator/where","title":"operator_to_string","content":"pub fn operator_to_string(\n  value: Operator,\n  dialect: Dialect,\n) -&gt; StringBuilder\n\nSynonyms:\nkreator/where.operator_to_string\nkreator/where operator_to_string","url":"kreator/where.html#operator_to_string"},{"doc":"kreator/where","title":"or_where_equals","content":"pub fn or_where_equals(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.or_where_equals\nkreator/where or_where_equals","url":"kreator/where.html#or_where_equals"},{"doc":"kreator/where","title":"or_where_gt","content":"pub fn or_where_gt(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.or_where_gt\nkreator/where or_where_gt","url":"kreator/where.html#or_where_gt"},{"doc":"kreator/where","title":"or_where_gte","content":"pub fn or_where_gte(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.or_where_gte\nkreator/where or_where_gte","url":"kreator/where.html#or_where_gte"},{"doc":"kreator/where","title":"or_where_in","content":"pub fn or_where_in(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.or_where_in\nkreator/where or_where_in","url":"kreator/where.html#or_where_in"},{"doc":"kreator/where","title":"or_where_like","content":"pub fn or_where_like(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.or_where_like\nkreator/where or_where_like","url":"kreator/where.html#or_where_like"},{"doc":"kreator/where","title":"or_where_lt","content":"pub fn or_where_lt(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.or_where_lt\nkreator/where or_where_lt","url":"kreator/where.html#or_where_lt"},{"doc":"kreator/where","title":"or_where_lte","content":"pub fn or_where_lte(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.or_where_lte\nkreator/where or_where_lte","url":"kreator/where.html#or_where_lte"},{"doc":"kreator/where","title":"or_where_not_equals","content":"pub fn or_where_not_equals(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.or_where_not_equals\nkreator/where or_where_not_equals","url":"kreator/where.html#or_where_not_equals"},{"doc":"kreator/where","title":"or_where_not_in","content":"pub fn or_where_not_in(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.or_where_not_in\nkreator/where or_where_not_in","url":"kreator/where.html#or_where_not_in"},{"doc":"kreator/where","title":"or_where_not_like","content":"pub fn or_where_not_like(\n  where_list: List(Where),\n  column: String,\n  value: Value,\n) -&gt; List(Where)\n\nSynonyms:\nkreator/where.or_where_not_like\nkreator/where or_where_not_like","url":"kreator/where.html#or_where_not_like"},{"doc":"kreator/where","title":"type_to_string","content":"pub fn type_to_string(\n  value: WhereType,\n  dialect: Dialect,\n) -&gt; StringBuilder\n\nSynonyms:\nkreator/where.type_to_string\nkreator/where type_to_string","url":"kreator/where.html#type_to_string"},{"doc":"kreator/where","title":"values","content":"pub fn values(where_list: List(Where)) -&gt; List(Value)\n\nSynonyms:\nkreator/where.values\nkreator/where values","url":"kreator/where.html#values"},{"doc":"kreator/where","title":"kreator/where","content":"","url":"kreator/where.html"},{"doc":"kreator/query","title":"Query","content":"pub type Query {\n  Query(sql: String, bindings: List(Value))\n}\n\nQuery(sql: String, bindings: List(Value))\n\n\nSynonyms:\nkreator/query.Query\nkreator/query Query","url":"kreator/query.html#Query"},{"doc":"kreator/query","title":"destruct","content":"pub fn destruct(query: Query) -&gt; #(String, List(Value))\n\nSynonyms:\nkreator/query.destruct\nkreator/query destruct","url":"kreator/query.html#destruct"},{"doc":"kreator/query","title":"kreator/query","content":"","url":"kreator/query.html"},{"doc":"kreator","title":"Method","content":"pub opaque type Method\n\n The method of the query.\n This is what defines if the query is a select, insert, update, or delete.\n\n\nSynonyms:\nkreator.Method\nkreator Method","url":"kreator.html#Method"},{"doc":"kreator","title":"Plan","content":"pub opaque type Plan\n\n The plan of the query. Contains all the instructions needed to build a query string.\n\n\nSynonyms:\nkreator.Plan\nkreator Plan","url":"kreator.html#Plan"},{"doc":"kreator","title":"and_where","content":"pub fn and_where(\n  plan: Plan,\n  fun: fn(List(Where)) -&gt; List(Where),\n) -&gt; Plan\n\n Used to add where clauses to the plan. Receives a function where the\n parameter is a new empty list of where clauses and it should return\n a list clauses. The difference from [where](#where) and\n [or_where](#or_where) is that this function will\n generate wrapped where clauses with `AND`.\n\nSynonyms:\nkreator.and_where\nkreator and_where","url":"kreator.html#and_where"},{"doc":"kreator","title":"delete","content":"pub fn delete(plan: Plan) -&gt; Plan\n\n Transforms the plan into a delete query. Will not fail if no where was set.\n\nSynonyms:\nkreator.delete\nkreator delete","url":"kreator.html#delete"},{"doc":"kreator","title":"insert","content":"pub fn insert(plan: Plan, data: List(#(String, Value))) -&gt; Plan\n\n Transforms the plan into an insert query and sets the data to be inserted.\n It will not fail if the data is empty, tough the generated query will\n probably be invalid.\n\n &lt;details&gt;\n &lt;summary&gt;Example&lt;/summary&gt;\n\n\timport kreator.{table, insert, to_sqlite}\n\n\tpub fn insert_users() {\n\t  table(&quot;users&quot;)\n\t  |&gt; insert([(&quot;name&quot;, &quot;Bruno&quot;)])\n\t  |&gt; to_sqlite()\n\t  /// ==&gt; &quot;insert into `users` (`name`) values (?)&quot;\n\t}\n&lt;/details&gt;\nSynonyms:\nkreator.insert\nkreator insert","url":"kreator.html#insert"},{"doc":"kreator","title":"not_returning","content":"pub fn not_returning(plan: Plan) -&gt; Plan\n\nSynonyms:\nkreator.not_returning\nkreator not_returning","url":"kreator.html#not_returning"},{"doc":"kreator","title":"or_where","content":"pub fn or_where(\n  plan: Plan,\n  fun: fn(List(Where)) -&gt; List(Where),\n) -&gt; Plan\n\n Used to add where clauses to the plan. Receives a function where the\n parameter is a new empty list of where clauses and it should return\n a list clauses. The difference from [where](#where) and\n [and_where](#and_where) is that this function will\n generate wrapped where clauses with `Or`.\n\nSynonyms:\nkreator.or_where\nkreator or_where","url":"kreator.html#or_where"},{"doc":"kreator","title":"order_by","content":"pub fn order_by(\n  plan: Plan,\n  column column: String,\n  direction direction: Direction,\n) -&gt; Plan\n\n Add an order by clause to the plan. Can be used multiple times to add\n multiple order by clauses.\n\nSynonyms:\nkreator.order_by\nkreator order_by","url":"kreator.html#order_by"},{"doc":"kreator","title":"returning","content":"pub fn returning(plan: Plan, returning: List(String)) -&gt; Plan\n\n Set the columns to be returned.\n\n\n table(&quot;users&quot;) |&gt; select([&quot;name&quot;, &quot;id&quot;]) |&gt; returning(&quot;id&quot;) |&gt; to_sqlite() /// ==&gt; &quot;select `name`, `id` from `users` returning `id`&quot;\n\n\nSynonyms:\nkreator.returning\nkreator returning","url":"kreator.html#returning"},{"doc":"kreator","title":"select","content":"pub fn select(plan: Plan, select: List(String)) -&gt; Plan\n\n Set the columns on a select statement. By default the value is `[&quot;*&quot;]`.\n\n\n table(&quot;users&quot;) |&gt; select([&quot;name&quot;, &quot;id&quot;]) |&gt; to_sqlite() /// ==&gt; &quot;select `name`, `id` from `users`&quot;\n\n\nSynonyms:\nkreator.select\nkreator select","url":"kreator.html#select"},{"doc":"kreator","title":"table","content":"pub fn table(table: String) -&gt; Plan\n\n Start a new plan to build a query by setting the table. With just using this\n you can already create a simple select like this:\n\n\n table(&quot;users&quot;) |&gt; to_sqlite() /// ==&gt; &quot;select * from `users`&quot;\n\n If you want to know how to select specific columns you can jump to the [select](#select) function.\n\n\nSynonyms:\nkreator.table\nkreator table","url":"kreator.html#table"},{"doc":"kreator","title":"to_postgres","content":"pub fn to_postgres(plan: Plan) -&gt; Query\n\n Builds a query based on a `Plan` for the `Postgres`` dialect.\n\nSynonyms:\nkreator.to_postgres\nkreator to_postgres","url":"kreator.html#to_postgres"},{"doc":"kreator","title":"to_sqlite","content":"pub fn to_sqlite(plan: Plan) -&gt; Query\n\n Builds a query based on a `Plan` for the SQLite dialect.\n\nSynonyms:\nkreator.to_sqlite\nkreator to_sqlite","url":"kreator.html#to_sqlite"},{"doc":"kreator","title":"update","content":"pub fn update(plan: Plan, data: List(#(String, Value))) -&gt; Plan\n\n Transforms the plan into an unpdate query and sets the data to be updated.\n It will not fail if the data is empty, tough the generated query will\n probably be invalid. Also it will not fail if no where was set.\n\nSynonyms:\nkreator.update\nkreator update","url":"kreator.html#update"},{"doc":"kreator","title":"where","content":"pub fn where(\n  plan: Plan,\n  fun: fn(List(Where)) -&gt; List(Where),\n) -&gt; Plan\n\n Used to add where clauses to the plan. Receives a function where the\n parameter is the current list of where clauses and it should return\n the new where clauses. OBS.: those clauses will be unwrapped.\n\nSynonyms:\nkreator.where\nkreator where","url":"kreator.html#where"},{"doc":"kreator","title":"kreator","content":"","url":"kreator.html"},{"doc":"kreator/wrappers/pgo","title":"run","content":"pub fn run(\n  query: Query,\n  on conn: Connection,\n  expecting dynamic: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; Result(Returned(a), QueryError)\n\nSynonyms:\nkreator/wrappers/pgo.run\nkreator/wrappers/pgo run","url":"kreator/wrappers/pgo.html#run"},{"doc":"kreator/wrappers/pgo","title":"run_nil","content":"pub fn run_nil(\n  query: Query,\n  on conn: Connection,\n) -&gt; Result(Nil, QueryError)\n\nSynonyms:\nkreator/wrappers/pgo.run_nil\nkreator/wrappers/pgo run_nil","url":"kreator/wrappers/pgo.html#run_nil"},{"doc":"kreator/wrappers/pgo","title":"kreator/wrappers/pgo","content":"","url":"kreator/wrappers/pgo.html"},{"doc":"kreator/wrappers/sqlight","title":"first","content":"pub fn first(\n  query: Query,\n  on conn: Connection,\n  expecting dynamic: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; Result(a, Error)\n\nSynonyms:\nkreator/wrappers/sqlight.first\nkreator/wrappers/sqlight first","url":"kreator/wrappers/sqlight.html#first"},{"doc":"kreator/wrappers/sqlight","title":"run","content":"pub fn run(\n  query: Query,\n  on conn: Connection,\n  expecting dynamic: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; Result(List(a), Error)\n\nSynonyms:\nkreator/wrappers/sqlight.run\nkreator/wrappers/sqlight run","url":"kreator/wrappers/sqlight.html#run"},{"doc":"kreator/wrappers/sqlight","title":"run_nil","content":"pub fn run_nil(\n  query: Query,\n  on conn: Connection,\n) -&gt; Result(Nil, Error)\n\nSynonyms:\nkreator/wrappers/sqlight.run_nil\nkreator/wrappers/sqlight run_nil","url":"kreator/wrappers/sqlight.html#run_nil"},{"doc":"kreator/wrappers/sqlight","title":"kreator/wrappers/sqlight","content":"","url":"kreator/wrappers/sqlight.html"}]);